@@ -1,6 +1,7 @@
+#
 #  This file is part of WebDyne.
 #
-#  This software is Copyright (c) 2015 by Andrew Speer <andrew@webdyne.org>.
+#  This software is Copyright (c) 2016 by Andrew Speer <andrew@webdyne.org>.
 #
 #  This is free software, licensed under:
 #
@@ -54,7 +55,7 @@ use overload;
 
 #  Version information
 #
-$VERSION='1.241';
+$VERSION='1.243';
 
 
 #  Debug load
@@ -389,7 +390,12 @@ sub handler : method {
         #  early enough. Will only happen after first compile, so no major performance
         #  impact on CGI object recreation
         #
-        delete $self->{'_CGI'} if $WEBDYNE_CGI_PARAM_EXPAND;
+        #  Update: Re-init rather than delete or WebDyne::State worn't work
+        #
+        #delete $self->{'_CGI'} if $WEBDYNE_CGI_PARAM_EXPAND;
+        if ((my $cgi_or=$self->{'_CGI'}) && $WEBDYNE_CGI_PARAM_EXPAND) {
+            $cgi_or->init();
+        }
 
 
     }
@@ -825,30 +831,9 @@ sub init_class {
     # CGI::->method is needed because perl 5.6.0 will use WebDyne::CGI->method instead of
     # CGI->method. CGI::->method makes it happy
     CGI::->import('-no_xhtml', '-no_sticky');
-    #  Work around changes in compile method in CGI ver 4.14 and later
-    #
     my @cgi_compile=qw(:all area map unescapeHTML form col colgroup spacer nobr);
-    if (UNIVERSAL::can('CGI', '_tag_func')) {
-        #  New CGI. shift off ':all'; and create shortcuts for legacy tags
-        shift @cgi_compile;
-        foreach my $function (@cgi_compile) {
-            unless (UNIVERSAL::can('CGI', $function)) { 
-                *{"CGI::${function}"} = sub { return CGI::_tag_func($function,@_); };
-            }
-            foreach my $start_end ( qw/ start end / ) {
-                my $start_end_function = "${start_end}_${function}";
-                unless (UNIVERSAL::can('CGI', $start_end_function)) { 
-                    *{"CGI::${start_end_function}"} = sub { return CGI::_tag_func($start_end_function,@_); };
-                }
-            }
-        }
-    }
-    else {
-        #  Old CGI
-        #
-        CGI::->compile(@cgi_compile);
-        foreach (grep { !/^:/ } @cgi_compile) { map { CGI::->$_ } ("start_${_}", "end_${_}") }
-    }
+    CGI::->compile(@cgi_compile);
+    foreach (grep { !/^:/ } @cgi_compile) { map { CGI::->$_ } ("start_${_}", "end_${_}") }
 
 
     #  Make all errors non-fatal
@@ -866,6 +851,12 @@ sub init_class {
     #
     $CGI::DISABLE_UPLOADS=$WEBDYNE_CGI_DISABLE_UPLOADS;
     $CGI::POST_MAX=$WEBDYNE_CGI_POST_MAX;
+    
+    
+    #  Apparently not such good practice - but needed. 
+    #  Update. Now done via local() closer to method.
+    #
+    #$CGI::LIST_CONTEXT_WARN=0;
 
 
     #  Alias request method to just 'r' also
@@ -934,7 +925,7 @@ sub init_class {
             debug("eval call complete, $@, %s", Dumper(\@eval)); 
 
         };
-        if (!@eval || $@ || !defined($eval[0])) {
+        if (!@eval || $@ || !$eval[0]) {
 
             #  An error occurred - handle it and return.
             #
@@ -3015,7 +3006,7 @@ sub CGI_param_expand {
     #
     my $cgi_or=shift() ||
         return err("unable to get CGI object");
-    local $CGI::LIST_CONTEXT_WARN=0;
+    local($CGI::LIST_CONTEXT_WARN)=0;
     foreach my $param (grep /=/, $cgi_or->param()) {
         my(@pairs) = split(/[&;]/,$param);
         foreach my $pair (@pairs) {
@@ -3453,15 +3444,18 @@ A full man page with usage and examples is installed with the WebDyne module. Fu
 WebDyne web page, http://webdyne.org/ with a snapshot of current documentation in PDF format available in the module
 source /doc directory.
 
-=head1 Copyright and License
+=head1 LICENSE and COPYRIGHT
 
-WebDyne is Copyright (C) 2006-2010 Andrew Speer. Webdyne is dual licensed. It is released as free software released
-under the Gnu Public License (GPL), but is also available for commercial use under a proprietary license - please
-contact the author for further information.
+This file is part of WebDyne.
 
-WebDyne is written in Perl and uses modules from CPAN (the Comprehensive Perl Archive Network). CPAN modules are
-Copyright (C) the owner/author, and are available in source from CPAN directly. All CPAN modules used are covered by the
-Perl Artistic License.
+This software is Copyright (c) 2016 by Andrew Speer <andrew@webdyne.org>.
+
+This is free software, licensed under:
+
+  The GNU General Public License, Version 2, June 1991
+
+Full license text is available at:
+L<http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt>
 
 =head1 Author
 
